<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       itdavoodi.ir
 * @since      1.0.0
 *
 * @package    Likeposts
 * @subpackage Likeposts/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Likeposts
 * @subpackage Likeposts/public
 * @author     davoodi <it.davoodi@gmail.com>
 */
class Likeposts_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Likeposts_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Likeposts_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/likeposts-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Likeposts_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Likeposts_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/likeposts-public.js', array( 'jquery' ), $this->version, false );
       // wp_enqueue_script('like_post', get_template_directory_uri().'/js/post-like.js', array('jquery'), '1.0', true );
        wp_localize_script('like_post', 'ajax_var', array(
            'url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('ajax-nonce')
        ));
	}
    function show_like ()
    { ?>
        <p class="post-like">
        <a data-post_id="POST_ID" href="#">
        <span class="qtip like" title="I like this article"></span>
        </a>
        <span class="count">POST_LIKES_COUNT</span>
        </p>
<?php

}



    function post_like()
    {
        // Check for nonce security
        $nonce = $_POST['nonce'];

        if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) )
            die ( 'Busted!');

        if(isset($_POST['post_like']))
        {
            // Retrieve user IP address
            $ip = $_SERVER['REMOTE_ADDR'];
            $post_id = $_POST['post_id'];

            // Get voters'IPs for the current post
            $meta_IP = get_post_meta($post_id, "voted_IP");
            $voted_IP = $meta_IP[0];

            if(!is_array($voted_IP))
                $voted_IP = array();

            // Get votes count for the current post
            $meta_count = get_post_meta($post_id, "votes_count", true);

            // Use has already voted ?
            if(!$this->hasAlreadyVoted($post_id))
            {
                $voted_IP[$ip] = time();

                // Save IP and increase votes count
                update_post_meta($post_id, "voted_IP", $voted_IP);
                update_post_meta($post_id, "votes_count", ++$meta_count);

                // Display count (ie jQuery return value)
                echo $meta_count;
            }
            else
                echo "already";
        }
        exit;
    }

    function hasAlreadyVoted($post_id)
    {
        global $timebeforerevote;

        // Retrieve post votes IPs
        $meta_IP = get_post_meta($post_id, "voted_IP");
        $voted_IP = $meta_IP[0];

        if(!is_array($voted_IP))
            $voted_IP = array();

        // Retrieve current user IP
        $ip = $_SERVER['REMOTE_ADDR'];

        // If user has already voted
        if(in_array($ip, array_keys($voted_IP)))
        {
            $time = $voted_IP[$ip];
            $now = time();

            // Compare between current time and vote time
            if(round(($now - $time) / 60) > $timebeforerevote)
                return false;

            return true;
        }

        return false;
    }
    function getPostLikeLink($post_id)
    {
        $themename = "twentyeleven";

        $vote_count = get_post_meta($post_id, "votes_count", true);

        $output = '<p class="post-like">';
        if($this->hasAlreadyVoted($post_id))
            $output .= ' <span title="'.__('I like this article', $themename).'" class="like alreadyvoted"></span>';
        else
            $output .= '<a href="#" data-post_id="'.$post_id.'">
					<span  title="'.__('I like this article', $themename).'"class="qtip like"></span>
				</a>';
        $output .= '<span class="count">'.$vote_count.'</span></p>';

        echo $output;
    }

}
